@@ -454,7 +454,7 @@ pub fn test_flip() {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let example = "Tile 2311:
 ..##.#..#.
